==> BEAR-0.9.23.tgz: BEAR-0.9.23/BEAR/Emoji/Conf/Ezweb.php <==
<?php
/**
 * BEAR
 *
 * PHP versions 5
 *
 * @category   BEAR
 * @package    BEAR_Emoji
 * @author     Akihito Koriyama <koriyama@bear-project.net>
 * @copyright  2008-2011 Akihito Koriyama All rights reserved.
 * @license    http://opensource.org/licenses/bsd-license.php BSD
 * @version    SVN: Release: @package_version@ $Id:$
 * @link       http://www.bear-project.net/
 */

/**
 * スタティック絵文字データ for Ezweb
 */

/** @noinspection PhpDuplicateArrayKeysInspection */
$emojiChars = array(
    'SUN' => '&#63072;',
    'CLOUD' => '&#63077;',
    'RAIN' => '&#63076;',
    'SNOW' => '&#63069;',
    'THUNDER' => '&#63071;',
    'TYPHOON' => '&#63041;',
    'FOG' => '&#63413;',
    'DRIZZLE' => '&#62396;',
    'ARIES' => '&#63079;',
    'TAURUS' => '&#63080;',
    'GEMINI' => '&#63081;',
    'CANCER' => '&#63082;',
    'LEO' => '&#63083;',
    'VIRGO' => '&#63084;',
    'LIBRA' => '&#63085;',
    'SCORPIO' => '&#63086;',
    'SAGITTARIUS' => '&#63087;',
    'CAPRICORN' => '&#63088;',
    'AQUARIUS' => '&#63089;',
    'PISCES' => '&#63090;',
    'SPORTS1' => '&#63667;',
    'BASEBALL' => '&#63123;',
    'GOLF' => '&#63414;',
    'TENNIS' => '&#63120;',
    'SOCCER' => '&#63119;',
    'SKIING' => '&#62336;',
    'BASKETBALL' => '&#63415;',
    'MOTORSPORTS' => '&#63122;',
    'POKEBERU' => '&#63416;',
    'TRAIN' => '&#63118;',
    'SUBWAY' => '&#63468;',
    'SHINKANSEN' => '&#63113;',
    'CAR1' => '&#63114;',
    'CAR2' => '&#63114;',
    'BUS' => '&#63112;',
    'SHIP' => '&#62293;',
    'PLAIN' => '&#63116;',
    'HOME' => '&#63108;',
    'BUILDING' => '&#63110;',
    'POSTOFFICE' => '&#62289;',
    'HOSPITAL' => '&#62290;',
    'BANK' => '&#63107;',
    'ATM' => '&#63099;',
    'HOTEL' => '&#62292;',
    'CONVENI' => '&#63100;',
    'GAS' => '&#63374;',
    'PARKING' => '&#63102;',
    'SIGN' => '&#63042;',
    'TOILE' => '&#63101;',
    'RESTRAN' => '&#63109;',
    'CAF?' => '&#63412;',
    'BAR' => '&#63131;',
    'BEER' => '&#63132;',
    'FASTFOOD' => '&#63151;',
    'SHOP' => '&#63219;',
    'SALON' => '&#63215;',
    'KARAOKE' => '&#63196;',
    'MOVIE' => '&#63216;',
    'YA1' => '&#63345;',
    'TOYS' => '&#63706;',
    'ENTAME' => '&#63201;',
    'ART' => '&#63417;',
    'PLAY' => '&#62409;',
    'EVENT' => '&#63419;',
    'TICKET' => '&#63094;',
    'SMOKING' => '&#63061;',
    'NOSMOKING' => '&#63062;',
    'CAMERA' => '&#63214;',
    'BAG' => '&#63092;',
    'BOOK' => '&#63095;',
    'RIBBON' => '&#63420;',
    'PRESENT' => '&#63144;',
    'BIRTHDAY' => '&#63421;',
    'PHONE' => '&#63411;',
    'MOBILE' => '&#63397;',
    'MEMO' => '&#62309;',
    'TV' => '&#63195;',
    'GAME' => '&#63135;',
    'CD' => '&#63205;',
    'HEART1' => '&#62328;',
    'SPADE' => '&#63422;',
    'DIAMOND' => '&#63423;',
    'CLUB' => '&#63424;',
    'EYE' => '&#63425;',
    'EAR' => '&#63426;',
    'HAND1' => '&#62600;',
    'HAND2' => '&#63427;',
    'HAND3' => '&#63428;',
    'YA2' => '&#63337;',
    'YA3' => '&#63336;',
    'FOOT' => '&#62443;',
    'SHOES' => '&#62444;',
    'GLASSES' => '&#63191;',
    'WHEELCHAIR' => '&#63063;',
    'MOON1' => '&#63429;',
    'MOON2' => '&#63430;',
    'MOON3' => '&#63431;',
    'MOON4' => '&#63070;',
    'MOON5' => '○',
    'DOG' => '&#63162;',
    'CAT1' => '&#63156;',
    'RESORT' => '&#63117;',
    'CHRISTMAS' => '&#63138;',
    'YA4' => '&#63346;',
    'PHONETO' => '&#63455;',
    'MAILTO' => '&#62566;',
    'FAXTO' => '&#63225;',
    'IMODE1' => '&#63861;',
    'IMODE2' => '&#63862;',
    'MAIL' => '&#63226;',
    'DOCOMO' => '&#63864;',
    'DOCOMOPOINT' => '&#63865;',
    'CHARGE' => '&#63386;',
    'FREE' => '&#63381;',
    'ID' => '&#62299;',
    'PASSWORD' => '&#63218;',
    'RETURN' => '&#63353;',
    'CLEAR' => '&#63432;',
    'SEARCH' => '&#63217;',
    'NEW' => '&#63461;',
    'GPS' => '&#62445;',
    'FREEDIAL' => '&#63876;',
    'SHARPDIAL' => '&#62601;',
    'Q' => '&#63060;',
    'NUM01' => '&#63227;',
    'NUM02' => '&#63228;',
    'NUM03' => '&#63296;',
    'NUM04' => '&#63297;',
    'NUM05' => '&#63298;',
    'NUM06' => '&#63299;',
    'NUM07' => '&#63300;',
    'NUM08' => '&#63301;',
    'NUM09' => '&#63302;',
    'NUM00' => '&#63433;',
    'OK1' => '&#63434;',
    'HEART2' => '&#63410;',
    'HEART3' => '&#62585;',
    'HEARTBREAK' => '&#63055;',
    'HEART4' => '&#63056;',
    'FACE1' => '&#63049;',
    'FACE2' => '&#63050;',
    'FACE3' => '&#62356;',
    'FACE4' => '&#62359;',
    'FACE5' => '&#63435;',
    'GOOD' => '&#62446;',
    'ONPU' => '&#63470;',
    'ONSEN' => '&#63125;',
    'MIDASHI' => '&#63314;',
    'KISS' => '&#63172;',
    'KIRAKIRA' => '&#62334;',
    'HINT' => '&#63054;',
    'ANGER' => '&#63166;',
    'PUNCH' => '&#63180;',
    'BOMB' => '&#63058;',
    'MOOD' => '&#63198;',
    'BAD' => '&#62447;',
    'SLEEP' => '&#63053;',
    'BIKKURI' => '&#63066;',
    'QUESTION' => '&#62448;',
    'BIKKURI2' => '&#62449;',
    'DON' => '&#63437;',
    'ASE1' => '&#63438;',
    'ASE2' => '&#63167;',
    'DASH' => '&#63181;',
    'SIGN1' => '&#63918;',
    'SIGN2' => '&#62450;',
    'CLAPPERBOARD' => '&#63127;',
    'FUKURO' => '&#63825;',
    'PEN1' => '&#63450;',
    'SHADOW' => '&#63829;',
    'CHAIR' => '&#63830;',
    'NIGHT' => '&#62405;',
    'SOON' => '&#63835;',
    'ON' => '&#63836;',
    'END' => '&#63837;',
    'SCHEDULE' => '&#63409;',
    'IAPP1' => '&#63921;',
    'IAPP2' => '&#63922;',
    'TSHIRT' => '&#63462;',
    'GAMA' => '&#63197;',
    'MAKEUP' => '&#63202;',
    'ZUBON' => '&#62587;',
    'SPORTS2' => '&#63121;',
    'TIN' => '&#63211;',
    'DOOR' => '&#63929;',
    'MONEY' => '&#63136;',
    'PC' => '&#63464;',
    'HEARTMAIL' => '&#62588;',
    'TOOL' => '&#63396;',
    'PEN2' => '&#63097;',
    'CROWN' => '&#63481;',
    'RING' => '&#63213;',
    'WATCH1' => '&#63060;',
    'BICYCLE' => '&#63111;',
    'CUP' => '&#62338;',
    'WATCH2' => '&#63383;',
    'FACE6' => '&#62356;',
    'FACE7' => '&#62361;',
    'FACE8' => '&#63049;&#63438;',
    'FACE9' => '&#63478;',
    'FACE10' => '&#62561;',
    'FACE11' => '&#62365;',
    'FACE12' => '&#63476;',
    'OK2' => '&#63186;',
    'FACE13' => '&#63168;',
    'FACE14' => '&#63475;',
    'FACE15' => '&#62361;',
    'FACE16' => '&#62358;',
    'CAT2' => '&#62355;',
    'FACE16' => '&#63051;',
    'FACE17' => '&#62573;',
    'NG' => '&#63956;',
    'CLIP' => '&#63096;',
    'COPYRIGHT' => '&#63348;',
    'TM' => '&#63338;',
    'RUN' => '&#63043;',
    'MARUHI' => '&#63178;',
    'UPDATE' => '&#62589;',
    'R' => '&#63349;',
    'ALERT' => '&#63065;',
    'KIN' => '&#63965;',
    'AKI' => '&#62301;',
    'GOU' => '&#63967;',
    'MAN' => '&#62300;',
    'YA5' => '&#62590;',
    'YA6' => '&#62592;',
    'SCHOOL' => '&#62291;',
    'WAVE' => '&#62593;',
    'FUJI' => '&#63469;',
    'FOURLEAF' => '&#63212;',
    'CHERRY' => '&#63147;',
    'TULIP' => '&#63165;',
    'BANANA' => '&#62454;',
    'APPLE' => '&#62349;',
    'BUD' => '&#62594;',
    'MOMIJI' => '&#63143;',
    'SAKURA' => '&#63139;',
    'ONIGIRI' => '&#63150;',
    'CAKE' => '&#63145;',
    'TOKURI' => '&#62314;',
    'DONBURI' => '&#63441;',
    'BREAD' => '&#62339;',
    'SNAIL' => '&#62595;',
    'HIYOKO' => '&#63161;',
    'PENGIN' => '&#63157;',
    'FISH' => '&#63090;',
    'FACE18' => '&#62369;',
    'FACE19' => '&#62597;',
    'HORSE' => '&#63153;',
    'PIG' => '&#63159;',
    'WINE' => '&#63130;',
    'FACE20' => '&#63477;',
    'COMMENT' => '&#63190;'
);

==> BEAR-0.9.24.tgz: BEAR-0.9.24/BEAR/Emoji/Conf/Ezweb.php <==
<?php
/**
 * BEAR
 *
 * PHP versions 5
 *
 * @category   BEAR
 * @package    BEAR_Emoji
 * @author     Akihito Koriyama <akihito.koriyama@gmail.com>
 * @copyright  2008-2015 Akihito Koriyama All rights reserved.
 * @license    http://opensource.org/licenses/bsd-license.php BSD
 * @version    @package_version@
 * @link       https://github.com/bearsaturday
 */

/**
 * スタティック絵文字データ for Ezweb
 */

/** @noinspection PhpDuplicateArrayKeysInspection */
$emojiChars = array(
    'SUN' => '&#63072;',
    'CLOUD' => '&#63077;',
    'RAIN' => '&#63076;',
    'SNOW' => '&#63069;',
    'THUNDER' => '&#63071;',
    'TYPHOON' => '&#63041;',
    'FOG' => '&#63413;',
    'DRIZZLE' => '&#62396;',
    'ARIES' => '&#63079;',
    'TAURUS' => '&#63080;',
    'GEMINI' => '&#63081;',
    'CANCER' => '&#63082;',
    'LEO' => '&#63083;',
    'VIRGO' => '&#63084;',
    'LIBRA' => '&#63085;',
    'SCORPIO' => '&#63086;',
    'SAGITTARIUS' => '&#63087;',
    'CAPRICORN' => '&#63088;',
    'AQUARIUS' => '&#63089;',
    'PISCES' => '&#63090;',
    'SPORTS1' => '&#63667;',
    'BASEBALL' => '&#63123;',
    'GOLF' => '&#63414;',
    'TENNIS' => '&#63120;',
    'SOCCER' => '&#63119;',
    'SKIING' => '&#62336;',
    'BASKETBALL' => '&#63415;',
    'MOTORSPORTS' => '&#63122;',
    'POKEBERU' => '&#63416;',
    'TRAIN' => '&#63118;',
    'SUBWAY' => '&#63468;',
    'SHINKANSEN' => '&#63113;',
    'CAR1' => '&#63114;',
    'CAR2' => '&#63114;',
    'BUS' => '&#63112;',
    'SHIP' => '&#62293;',
    'PLAIN' => '&#63116;',
    'HOME' => '&#63108;',
    'BUILDING' => '&#63110;',
    'POSTOFFICE' => '&#62289;',
    'HOSPITAL' => '&#62290;',
    'BANK' => '&#63107;',
    'ATM' => '&#63099;',
    'HOTEL' => '&#62292;',
    'CONVENI' => '&#63100;',
    'GAS' => '&#63374;',
    'PARKING' => '&#63102;',
    'SIGN' => '&#63042;',
    'TOILE' => '&#63101;',
    'RESTRAN' => '&#63109;',
    'CAF?' => '&#63412;',
    'BAR' => '&#63131;',
    'BEER' => '&#63132;',
    'FASTFOOD' => '&#63151;',
    'SHOP' => '&#63219;',
    'SALON' => '&#63215;',
    'KARAOKE' => '&#63196;',
    'MOVIE' => '&#63216;',
    'YA1' => '&#63345;',
    'TOYS' => '&#63706;',
    'ENTAME' => '&#63201;',
    'ART' => '&#63417;',
    'PLAY' => '&#62409;',
    'EVENT' => '&#63419;',
    'TICKET' => '&#63094;',
    'SMOKING' => '&#63061;',
    'NOSMOKING' => '&#63062;',
    'CAMERA' => '&#63214;',
    'BAG' => '&#63092;',
    'BOOK' => '&#63095;',
    'RIBBON' => '&#63420;',
    'PRESENT' => '&#63144;',
    'BIRTHDAY' => '&#63421;',
    'PHONE' => '&#63411;',
    'MOBILE' => '&#63397;',
    'MEMO' => '&#62309;',
    'TV' => '&#63195;',
    'GAME' => '&#63135;',
    'CD' => '&#63205;',
    'HEART1' => '&#62328;',
    'SPADE' => '&#63422;',
    'DIAMOND' => '&#63423;',
    'CLUB' => '&#63424;',
    'EYE' => '&#63425;',
    'EAR' => '&#63426;',
    'HAND1' => '&#62600;',
    'HAND2' => '&#63427;',
    'HAND3' => '&#63428;',
    'YA2' => '&#63337;',
    'YA3' => '&#63336;',
    'FOOT' => '&#62443;',
    'SHOES' => '&#62444;',
    'GLASSES' => '&#63191;',
    'WHEELCHAIR' => '&#63063;',
    'MOON1' => '&#63429;',
    'MOON2' => '&#63430;',
    'MOON3' => '&#63431;',
    'MOON4' => '&#63070;',
    'MOON5' => '○',
    'DOG' => '&#63162;',
    'CAT1' => '&#63156;',
    'RESORT' => '&#63117;',
    'CHRISTMAS' => '&#63138;',
    'YA4' => '&#63346;',
    'PHONETO' => '&#63455;',
    'MAILTO' => '&#62566;',
    'FAXTO' => '&#63225;',
    'IMODE1' => '&#63861;',
    'IMODE2' => '&#63862;',
    'MAIL' => '&#63226;',
    'DOCOMO' => '&#63864;',
    'DOCOMOPOINT' => '&#63865;',
    'CHARGE' => '&#63386;',
    'FREE' => '&#63381;',
    'ID' => '&#62299;',
    'PASSWORD' => '&#63218;',
    'RETURN' => '&#63353;',
    'CLEAR' => '&#63432;',
    'SEARCH' => '&#63217;',
    'NEW' => '&#63461;',
    'GPS' => '&#62445;',
    'FREEDIAL' => '&#63876;',
    'SHARPDIAL' => '&#62601;',
    'Q' => '&#63060;',
    'NUM01' => '&#63227;',
    'NUM02' => '&#63228;',
    'NUM03' => '&#63296;',
    'NUM04' => '&#63297;',
    'NUM05' => '&#63298;',
    'NUM06' => '&#63299;',
    'NUM07' => '&#63300;',
    'NUM08' => '&#63301;',
    'NUM09' => '&#63302;',
    'NUM00' => '&#63433;',
    'OK1' => '&#63434;',
    'HEART2' => '&#63410;',
    'HEART3' => '&#62585;',
    'HEARTBREAK' => '&#63055;',
    'HEART4' => '&#63056;',
    'FACE1' => '&#63049;',
    'FACE2' => '&#63050;',
    'FACE3' => '&#62356;',
    'FACE4' => '&#62359;',
    'FACE5' => '&#63435;',
    'GOOD' => '&#62446;',
    'ONPU' => '&#63470;',
    'ONSEN' => '&#63125;',
    'MIDASHI' => '&#63314;',
    'KISS' => '&#63172;',
    'KIRAKIRA' => '&#62334;',
    'HINT' => '&#63054;',
    'ANGER' => '&#63166;',
    'PUNCH' => '&#63180;',
    'BOMB' => '&#63058;',
    'MOOD' => '&#63198;',
    'BAD' => '&#62447;',
    'SLEEP' => '&#63053;',
    'BIKKURI' => '&#63066;',
    'QUESTION' => '&#62448;',
    'BIKKURI2' => '&#62449;',
    'DON' => '&#63437;',
    'ASE1' => '&#63438;',
    'ASE2' => '&#63167;',
    'DASH' => '&#63181;',
    'SIGN1' => '&#63918;',
    'SIGN2' => '&#62450;',
    'CLAPPERBOARD' => '&#63127;',
    'FUKURO' => '&#63825;',
    'PEN1' => '&#63450;',
    'SHADOW' => '&#63829;',
    'CHAIR' => '&#63830;',
    'NIGHT' => '&#62405;',
    'SOON' => '&#63835;',
    'ON' => '&#63836;',
    'END' => '&#63837;',
    'SCHEDULE' => '&#63409;',
    'IAPP1' => '&#63921;',
    'IAPP2' => '&#63922;',
    'TSHIRT' => '&#63462;',
    'GAMA' => '&#63197;',
    'MAKEUP' => '&#63202;',
    'ZUBON' => '&#62587;',
    'SPORTS2' => '&#63121;',
    'TIN' => '&#63211;',
    'DOOR' => '&#63929;',
    'MONEY' => '&#63136;',
    'PC' => '&#63464;',
    'HEARTMAIL' => '&#62588;',
    'TOOL' => '&#63396;',
    'PEN2' => '&#63097;',
    'CROWN' => '&#63481;',
    'RING' => '&#63213;',
    'WATCH1' => '&#63060;',
    'BICYCLE' => '&#63111;',
    'CUP' => '&#62338;',
    'WATCH2' => '&#63383;',
    'FACE6' => '&#62356;',
    'FACE7' => '&#62361;',
    'FACE8' => '&#63049;&#63438;',
    'FACE9' => '&#63478;',
    'FACE10' => '&#62561;',
    'FACE11' => '&#62365;',
    'FACE12' => '&#63476;',
    'OK2' => '&#63186;',
    'FACE13' => '&#63168;',
    'FACE14' => '&#63475;',
    'FACE15' => '&#62361;',
    'FACE16' => '&#62358;',
    'CAT2' => '&#62355;',
    'FACE16' => '&#63051;',
    'FACE17' => '&#62573;',
    'NG' => '&#63956;',
    'CLIP' => '&#63096;',
    'COPYRIGHT' => '&#63348;',
    'TM' => '&#63338;',
    'RUN' => '&#63043;',
    'MARUHI' => '&#63178;',
    'UPDATE' => '&#62589;',
    'R' => '&#63349;',
    'ALERT' => '&#63065;',
    'KIN' => '&#63965;',
    'AKI' => '&#62301;',
    'GOU' => '&#63967;',
    'MAN' => '&#62300;',
    'YA5' => '&#62590;',
    'YA6' => '&#62592;',
    'SCHOOL' => '&#62291;',
    'WAVE' => '&#62593;',
    'FUJI' => '&#63469;',
    'FOURLEAF' => '&#63212;',
    'CHERRY' => '&#63147;',
    'TULIP' => '&#63165;',
    'BANANA' => '&#62454;',
    'APPLE' => '&#62349;',
    'BUD' => '&#62594;',
    'MOMIJI' => '&#63143;',
    'SAKURA' => '&#63139;',
    'ONIGIRI' => '&#63150;',
    'CAKE' => '&#63145;',
    'TOKURI' => '&#62314;',
    'DONBURI' => '&#63441;',
    'BREAD' => '&#62339;',
    'SNAIL' => '&#62595;',
    'HIYOKO' => '&#63161;',
    'PENGIN' => '&#63157;',
    'FISH' => '&#63090;',
    'FACE18' => '&#62369;',
    'FACE19' => '&#62597;',
    'HORSE' => '&#63153;',
    'PIG' => '&#63159;',
    'WINE' => '&#63130;',
    'FACE20' => '&#63477;',
    'COMMENT' => '&#63190;'
);
